package access

import (
	"encoding/json"
	"fmt"
	"io/ioutil"
	"os"

	"github.com/dgrijalva/jwt-go"
	"github.com/gofiber/fiber/v2"
)

var accessRules map[string]map[string]map[string][]string

func Init() {
	jsonFile, err := os.Open("access.json")
	if err != nil {
		fmt.Println(err)
	}
	byteValue, _ := ioutil.ReadAll(jsonFile)
	json.Unmarshal(byteValue, &accessRules)

	defer jsonFile.Close()
}

func CheckAccess(c *fiber.Ctx, modelName string, tokenString string) bool {
	rules := accessRules[modelName][c.Method()]
	if rules == nil {
		return false
	}

	token, err := jwt.Parse(tokenString, func(token *jwt.Token) (interface{}, error) {
		if _, ok := token.Method.(*jwt.SigningMethodHMAC); !ok {
			return nil, fmt.Errorf("unexpected signing method: %v", token.Header["alg"])
		}
		return []byte(os.Getenv("ACCESS_SECRET")), nil
	})

	if err != nil {
		return false
	}

	claims, err_claims := token.Claims.(jwt.MapClaims)
	if !err_claims {
		return false
	}

	// User access
	for _, item := range rules["users"] {
		if (item == claims["login"]) || (item == "*") {
			return true
		}
	}

	// Groups access
	claimsGroups := claims["groups"].([]interface{})
	uGrups := make([]string, len(claimsGroups))
	for i, v := range claimsGroups {
		uGrups[i] = v.(string)
	}

	for _, rgroup := range rules["groups"] {
		for _, ugroup := range uGrups {
			if (ugroup == rgroup) || rgroup == "*" {
				return true
			}
		}
	}

	return false
}
